/*
	Paramete file for YUV/CCIR-656 to RGB-888 color space convertor
	
	File		: YUV2RGB_conv.h

	Designer	: Masami IKURA [ MASATIKU ]
	Organize	: KURUSUGAWA Electronics Industry Inc,.
	Revision	: Rev0.1
	Syntax		: NSL language set
	Resume		: 091026 first design.
*/

// Original equation
//	R = 1.164(Y-16)                + 1.596(V-128)
//	G = 1.164(Y-16) - 0.391(U-128) - 0.813(V-128)
//	B = 1.164(Y-16) + 2.018(U-128)

// Implement equation
//	R = 1.164*Y + 0.000*U + 1.596*V - 222.912
//	G = 1.164*Y - 0.391*U - 0.813*V + 135.488
//	B = 1.164*Y + 2.018*U + 0.000*V - 276.928

//	ex)
//		1) YCbCr = eb/80/80 = 235/128/128
//			RGB = 255/255/255


//		x4096	coefficient
//		x128	constant value

	#define		COEF_R1		16'h12A0	// Y
	#define		COEF_R2		16'h0000	// U
	#define		COEF_R3		16'h1989	// V
	#define		COEF_R4		16'd28532	// Constant value (+)

	#define		COEF_G1		16'h12A0	// Y
	#define		COEF_G2		16'h0641	// U
	#define		COEF_G3		16'h0d02	// V
	#define		COEF_G4		16'd17342	// Constant value (+)

	#define		COEF_B1		16'h12A0	// Y
	#define		COEF_B2		16'h2049	// U
	#define		COEF_B3		16'h0000	// V
	#define		COEF_B4		16'd35446	// Constant value (+)

declare YUV2RGB_conv {

// CCIR-656 data input
	input		Yin[8] ;
	input		Uin[8] ;
	input		Vin[8] ;
	
// RGB-888 data output
	output		Rout[8] ;
	output		Gout[8] ;
	output		Bout[8] ;
	
// Control lines
	input		VSYNCin ;				// VSYNC in
	input		HSYNCin ;				// HSYNC in
	
	output		VSYNCout ;				// Pipeline clock conpensated VSYNC out
	output		HSYNCout ;				// Pipeline clock conpensated HSYNC out

// Function control
	func_in		ConvStart() ;
	func_out	ConvFinish() ;
}
